/**
 * @version $Id$
 * @package DJ-ImageScroller
 * @subpackage DJ-ImageSlider Component
 * @copyright Copyright (C) 2017 DJ-Extensions.com, All rights reserved.
 * @license DJ-Extensions.com Proprietary Use License
 * @author url: http://dj-extensions.com
 * @author email contact@dj-extensions.com
 * @developer Szymon Woronowski - szymon.woronowski@design-joomla.eu
 *
 */

(function($){

this.DJImageScrollerModule = new Class({

    initialize: function(settings){

    	$('djscroller' + settings.id).fade('hide');
    	
    	var timer = null;
    	var current_pos = 0;
        var slider = $('scroller' + settings.id);
        var interval = 20;
        var step = settings.speed * (interval / 1000);
		
		var slides = slider.getChildren('li');
		var slider_size = slides.length * settings.slide_size;
		var end_pos = (slides.length - settings.visible_slides) * settings.slide_size;
				
        if (Browser.ie8) { // only for IE8
			var visibles = new Array();
			for (var i = 0; i < settings.visible_slides; i++) {
				visibles[i] = slides[i];
				visibles[i].fade('hide');
			}
		}
		
        slider.setStyle('position', 'relative');
		
        var slideFx;
		if (settings.slider_type == 1) { // vertical
            slider.setStyle('top', 0);
            slider.setStyle('height', slider_size);
            slideFx = new Fx.Tween(slider, {
				property: 'top', 
                duration: interval,
                transition: 'linear',
                link: 'cancel'
            });
        } else { // horizontal
            slider.setStyle('left', 0);
            slider.setStyle('width', slider_size);
            slideFx = new Fx.Tween(slider, {
				property: 'left', 
                duration: interval,
                transition: 'linear',
                link: 'cancel'
            });
        }

		$('djscroller-loader' + settings.id).addEvents({
            'mouseenter': function(){
            	clearInterval(timer);
            },
            'mouseleave': function(){
            	clearInterval(timer);
            	timer = slide.periodical(interval);
            },
            'swipe': function(event){
				if(event.direction == 'left') {
					//nextSlide();
				} else if(event.direction == 'right') {
					//prevSlide();
				}
			}
        });
        $('djscroller-loader' + settings.id).store('swipe:cancelVertical', true);
		
        function slide(){
        	
			if( - current_pos >= end_pos - step / 2 && - current_pos < end_pos + step / 2) {
				slider.grab(slides[0]);
				slides = slider.getChildren('li');
				current_pos += settings.slide_size;
			}
			
			current_pos -= step;
			slideFx.set(current_pos);
		}
        
		function responsive(){
			
			var wrapper = $('djscroller-loader' + settings.id).getParent();
			var parentWidth = wrapper.getSize().x;
			parentWidth -= wrapper.getStyle('padding-left').toInt();
			parentWidth -= wrapper.getStyle('padding-right').toInt();
			
			var maxWidth = $('djscroller' + settings.id).getStyle('max-width').toInt();
			var size = $('djscroller' + settings.id).getSize();
			var newSliderWidth = size.x;
			
			if(newSliderWidth > parentWidth) {
				newSliderWidth = parentWidth;
			} else if(newSliderWidth <= parentWidth && newSliderWidth < maxWidth){
				newSliderWidth = (parentWidth > maxWidth ? maxWidth : parentWidth);
			}
			
        	var ratio = size.x / size.y;
			var newSliderHeight = newSliderWidth / ratio;
			
			$('djscroller' + settings.id).setStyle('width', newSliderWidth);
			$('djscroller' + settings.id).setStyle('height', newSliderHeight);
			
        	if (settings.slider_type == 1) { // vertical
				
				var space = slides[0].getStyle('padding-bottom').toInt();
				settings.slide_size = (newSliderHeight + space) / settings.visible_slides;
				var current_size = slider_size;
		    	slider_size = slides.length * settings.slide_size + slides.length;
		    	current_pos = slider_size * current_pos / current_size;
		    	end_pos = (slides.length - settings.visible_slides) * settings.slide_size;
		        slider.setStyle('height', slider_size);
		        
		        slides.setStyle('width', newSliderWidth);
				slides.setStyle('height', settings.slide_size - space);
				slideFx.set(current_pos);
		        
		    } else { // horizontal
		    	
		    	var space = slides[0].getStyle('padding-right').toInt();
		    	settings.slide_size = (newSliderWidth + space) / settings.visible_slides;
		    	var current_size = slider_size;
		    	slider_size = slides.length * settings.slide_size + slides.length;
		    	current_pos = slider_size * current_pos / current_size;
		    	end_pos = (slides.length - settings.visible_slides) * settings.slide_size;
		        slider.setStyle('width', slider_size);
		        
		        slides.setStyle('width', settings.slide_size - space);
				slides.setStyle('height', newSliderHeight);
				slideFx.set(current_pos);
		    }
		}
		
		function sliderLoaded(){
			// hide loader and show slider
			$('djscroller-loader' + settings.id).setStyle('background','none');
			
			$('djscroller' + settings.id).fade('in');
			
			if (Browser.ie8) { // only for IE8
				visibles.each(function(el){
					if(el) el.fade('in');
				});
			}
			
			responsive();
			
			timer = slide.periodical(interval);
		}
		
		if(settings.preload) sliderLoaded.delay(settings.preload);
		//else if (DocumentLoaded) sliderLoaded();
		else window.addEvent('load', sliderLoaded);
		
		window.addEvent('resize', responsive);
        
    }
    
});

})(document.id);